from gevent import monkey
monkey.patch_all()

from werkzeug.serving import run_simple
from flask_cors import CORS
from pymongo import MongoClient

from src.config import Config
from src.singletons.database_singleton import DatabaseSingleton

from src.infra.server import app, socketio
from src.controllers.user_controller import user_blueprint
from src.controllers.reservation_controller import reservation_blueprint
from src.controllers.health_controller import health_blueprint
from src.controllers.room_controller import room_blueprint

CORS(app)
app.config['JWT_SECRET_KEY'] = Config.JWT_SECRET_KEY

app.register_blueprint(user_blueprint, url_prefix='/user')
app.register_blueprint(reservation_blueprint, url_prefix='/reservation')
app.register_blueprint(room_blueprint, url_prefix='/room')
app.register_blueprint(health_blueprint, url_prefix='/health')

client = MongoClient(Config.MONGO_URI)
db = DatabaseSingleton.get_instance()

if db is not None:
    print('Connected to MongoDB')
else:
    print('Failed to connect to MongoDB')

def create_app():
    return app

if __name__ == '__main__':
    #app.run(debug=True)
    socketio.run(app, host=Config.APP_HOST, debug=False)